@@ -3,7 +3,6 @@ package Bubblegum::Object::Universal;
 
 use 5.10.0;
 use namespace::autoclean;
-
 use Bubblegum::Namespace;
 
 use Scalar::Util ();
@@ -12,128 +11,145 @@ use Types::Standard ();
 use Class::Load 'load_class';
 
 our @ISA = (); # non-object
+my  $TYPES = $Bubblegum::Namespace::ExtendedTypes;
 
-our $VERSION = '0.40'; # VERSION
-
-*asa_aref       = \&Types::Standard::assert_ArrayRef;
-*asa_arrayref   = \&Types::Standard::assert_ArrayRef;
-*asa_bool       = \&Types::Standard::assert_Bool;
-*asa_boolean    = \&Types::Standard::assert_Bool;
-*asa_class      = \&Types::Standard::assert_ClassName;
-*asa_classname  = \&Types::Standard::assert_ClassName;
-*asa_coderef    = \&Types::Standard::assert_CodeRef;
-*asa_cref       = \&Types::Standard::assert_CodeRef;
-*asa_def        = \&Types::Standard::assert_Defined;
-*asa_defined    = \&Types::Standard::assert_Defined;
-*asa_fh         = \&Types::Standard::assert_FileHandle;
-*asa_filehandle = \&Types::Standard::assert_FileHandle;
-*asa_glob       = \&Types::Standard::assert_GlobRef;
-*asa_globref    = \&Types::Standard::assert_GlobRef;
-*asa_hashref    = \&Types::Standard::assert_HashRef;
-*asa_href       = \&Types::Standard::assert_HashRef;
-*asa_int        = \&Types::Standard::assert_Int;
-*asa_integer    = \&Types::Standard::assert_Int;
-*asa_nil        = \&Types::Standard::assert_Undef;
-*asa_null       = \&Types::Standard::assert_Undef;
-*asa_num        = \&Types::Standard::assert_Num;
-*asa_number     = \&Types::Standard::assert_Num;
-*asa_obj        = \&Types::Standard::assert_Object;
-*asa_object     = \&Types::Standard::assert_Object;
-*asa_ref        = \&Types::Standard::assert_Ref;
-*asa_reference  = \&Types::Standard::assert_Ref;
-*asa_regexpref  = \&Types::Standard::assert_RegexpRef;
-*asa_rref       = \&Types::Standard::assert_RegexpRef;
-*asa_scalarref  = \&Types::Standard::assert_ScalarRef;
-*asa_sref       = \&Types::Standard::assert_ScalarRef;
-*asa_str        = \&Types::Standard::assert_Str;
-*asa_string     = \&Types::Standard::assert_Str;
-*asa_undef      = \&Types::Standard::assert_Undef;
-*asa_undefined  = \&Types::Standard::assert_Undef;
-*asa_val        = \&Types::Standard::assert_Value;
-*asa_value      = \&Types::Standard::assert_Value;
-*isa_aref       = \&Types::Standard::is_ArrayRef;
-*isa_arrayref   = \&Types::Standard::is_ArrayRef;
-*isa_bool       = \&Types::Standard::is_Bool;
-*isa_boolean    = \&Types::Standard::is_Bool;
-*isa_class      = \&Types::Standard::is_ClassName;
-*isa_classname  = \&Types::Standard::is_ClassName;
-*isa_coderef    = \&Types::Standard::is_CodeRef;
-*isa_cref       = \&Types::Standard::is_CodeRef;
-*isa_def        = \&Types::Standard::is_Defined;
-*isa_defined    = \&Types::Standard::is_Defined;
-*isa_fh         = \&Types::Standard::is_FileHandle;
-*isa_filehandle = \&Types::Standard::is_FileHandle;
-*isa_glob       = \&Types::Standard::is_GlobRef;
-*isa_globref    = \&Types::Standard::is_GlobRef;
-*isa_hashref    = \&Types::Standard::is_HashRef;
-*isa_href       = \&Types::Standard::is_HashRef;
-*isa_int        = \&Types::Standard::is_Int;
-*isa_integer    = \&Types::Standard::is_Int;
-*isa_nil        = \&Types::Standard::is_Undef;
-*isa_null       = \&Types::Standard::is_Undef;
-*isa_num        = \&Types::Standard::is_Num;
-*isa_number     = \&Types::Standard::is_Num;
-*isa_obj        = \&Types::Standard::is_Object;
-*isa_object     = \&Types::Standard::is_Object;
-*isa_ref        = \&Types::Standard::is_Ref;
-*isa_reference  = \&Types::Standard::is_Ref;
-*isa_regexpref  = \&Types::Standard::is_RegexpRef;
-*isa_rref       = \&Types::Standard::is_RegexpRef;
-*isa_scalarref  = \&Types::Standard::is_ScalarRef;
-*isa_sref       = \&Types::Standard::is_ScalarRef;
-*isa_str        = \&Types::Standard::is_Str;
-*isa_string     = \&Types::Standard::is_Str;
-*isa_undef      = \&Types::Standard::is_Undef;
-*isa_undefined  = \&Types::Standard::is_Undef;
-*isa_val        = \&Types::Standard::is_Value;
-*isa_value      = \&Types::Standard::is_Value;
+our $VERSION = '0.41'; # VERSION
 
 sub digest {
-    my $self  = CORE::shift;
+    my $self = CORE::shift;
     return wrapper($self, 'Digest');
 }
 
+sub dump {
+    my $self = CORE::shift;
+    return dumper($self)->encode;
+}
+
 sub dumper {
-    my $self  = CORE::shift;
+    my $self = CORE::shift;
     return wrapper($self, 'Dumper');
 }
 
 sub encoder {
-    my $self  = CORE::shift;
+    my $self = CORE::shift;
     return wrapper($self, 'Encoder');
 }
 
 sub instance {
     my $self  = CORE::shift;
-    my $class = $$Bubblegum::Namespace::ExtendedTypes{'INSTANCE'};
-    return load_class($class)->new(data => $self);
+    my $class = $$TYPES{'INSTANCE'};
+    return load_class($class)->new(
+        data => $self
+    );
 }
 
 sub json {
-    my $self  = CORE::shift;
+    my $self = CORE::shift;
     return wrapper($self, 'Json');
 }
 
 sub refaddr {
-    return Scalar::Util::refaddr CORE::shift;
+    return Scalar::Util::refaddr(
+        CORE::shift
+    );
 }
 
 sub reftype {
-    return Scalar::Util::reftype CORE::shift;
+    return Scalar::Util::reftype(
+        CORE::shift
+    );
 }
 
 sub wrapper {
     my $self  = CORE::shift;
     my $class = CORE::shift;
-    my $wrapper = $$Bubblegum::Namespace::ExtendedTypes{'WRAPPER'};
-    return load_class(join('::', $wrapper, $class))->new(data => $self);
+    my $wrapper = $$TYPES{'WRAPPER'};
+    return load_class(join('::', $wrapper, $class))->new(
+        data => $self
+    );
 }
 
 sub yaml {
-    my $self  = CORE::shift;
+    my $self = CORE::shift;
     return wrapper($self, 'Yaml');
 }
 
+{
+    no warnings 'once';
+    *asa_aref       = \&Types::Standard::assert_ArrayRef;
+    *asa_arrayref   = \&Types::Standard::assert_ArrayRef;
+    *asa_bool       = \&Types::Standard::assert_Bool;
+    *asa_boolean    = \&Types::Standard::assert_Bool;
+    *asa_class      = \&Types::Standard::assert_ClassName;
+    *asa_classname  = \&Types::Standard::assert_ClassName;
+    *asa_coderef    = \&Types::Standard::assert_CodeRef;
+    *asa_cref       = \&Types::Standard::assert_CodeRef;
+    *asa_def        = \&Types::Standard::assert_Defined;
+    *asa_defined    = \&Types::Standard::assert_Defined;
+    *asa_fh         = \&Types::Standard::assert_FileHandle;
+    *asa_filehandle = \&Types::Standard::assert_FileHandle;
+    *asa_glob       = \&Types::Standard::assert_GlobRef;
+    *asa_globref    = \&Types::Standard::assert_GlobRef;
+    *asa_hashref    = \&Types::Standard::assert_HashRef;
+    *asa_href       = \&Types::Standard::assert_HashRef;
+    *asa_int        = \&Types::Standard::assert_Int;
+    *asa_integer    = \&Types::Standard::assert_Int;
+    *asa_nil        = \&Types::Standard::assert_Undef;
+    *asa_null       = \&Types::Standard::assert_Undef;
+    *asa_num        = \&Types::Standard::assert_Num;
+    *asa_number     = \&Types::Standard::assert_Num;
+    *asa_obj        = \&Types::Standard::assert_Object;
+    *asa_object     = \&Types::Standard::assert_Object;
+    *asa_ref        = \&Types::Standard::assert_Ref;
+    *asa_reference  = \&Types::Standard::assert_Ref;
+    *asa_regexpref  = \&Types::Standard::assert_RegexpRef;
+    *asa_rref       = \&Types::Standard::assert_RegexpRef;
+    *asa_scalarref  = \&Types::Standard::assert_ScalarRef;
+    *asa_sref       = \&Types::Standard::assert_ScalarRef;
+    *asa_str        = \&Types::Standard::assert_Str;
+    *asa_string     = \&Types::Standard::assert_Str;
+    *asa_undef      = \&Types::Standard::assert_Undef;
+    *asa_undefined  = \&Types::Standard::assert_Undef;
+    *asa_val        = \&Types::Standard::assert_Value;
+    *asa_value      = \&Types::Standard::assert_Value;
+    *isa_aref       = \&Types::Standard::is_ArrayRef;
+    *isa_arrayref   = \&Types::Standard::is_ArrayRef;
+    *isa_bool       = \&Types::Standard::is_Bool;
+    *isa_boolean    = \&Types::Standard::is_Bool;
+    *isa_class      = \&Types::Standard::is_ClassName;
+    *isa_classname  = \&Types::Standard::is_ClassName;
+    *isa_coderef    = \&Types::Standard::is_CodeRef;
+    *isa_cref       = \&Types::Standard::is_CodeRef;
+    *isa_def        = \&Types::Standard::is_Defined;
+    *isa_defined    = \&Types::Standard::is_Defined;
+    *isa_fh         = \&Types::Standard::is_FileHandle;
+    *isa_filehandle = \&Types::Standard::is_FileHandle;
+    *isa_glob       = \&Types::Standard::is_GlobRef;
+    *isa_globref    = \&Types::Standard::is_GlobRef;
+    *isa_hashref    = \&Types::Standard::is_HashRef;
+    *isa_href       = \&Types::Standard::is_HashRef;
+    *isa_int        = \&Types::Standard::is_Int;
+    *isa_integer    = \&Types::Standard::is_Int;
+    *isa_nil        = \&Types::Standard::is_Undef;
+    *isa_null       = \&Types::Standard::is_Undef;
+    *isa_num        = \&Types::Standard::is_Num;
+    *isa_number     = \&Types::Standard::is_Num;
+    *isa_obj        = \&Types::Standard::is_Object;
+    *isa_object     = \&Types::Standard::is_Object;
+    *isa_ref        = \&Types::Standard::is_Ref;
+    *isa_reference  = \&Types::Standard::is_Ref;
+    *isa_regexpref  = \&Types::Standard::is_RegexpRef;
+    *isa_rref       = \&Types::Standard::is_RegexpRef;
+    *isa_scalarref  = \&Types::Standard::is_ScalarRef;
+    *isa_sref       = \&Types::Standard::is_ScalarRef;
+    *isa_str        = \&Types::Standard::is_Str;
+    *isa_string     = \&Types::Standard::is_Str;
+    *isa_undef      = \&Types::Standard::is_Undef;
+    *isa_undefined  = \&Types::Standard::is_Undef;
+    *isa_val        = \&Types::Standard::is_Value;
+    *isa_value      = \&Types::Standard::is_Value;
+}
+
 1;
 
 __END__
@@ -148,7 +164,7 @@ Bubblegum::Object::Universal - Common Methods for Operating on Defined Values
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
